==> openGion_dev_5.6.8.0.zip: opengion/uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF73S.sql <==
/****************************************************************************/
/* GF73 ( 使用ｶﾗﾑ状態ﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2013/09/03 10:23:39                                            */
/****************************************************************************/
CREATE TABLE GF73 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (   1 )                 NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR ( 256 )                                                 /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR (  60 )                                                 /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR ( 256 )                                                 /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR (  14 )                                                 /*  60 最終更新日   */
 , TAGNAME      VARCHAR (  30 )                                                 /*  80 ﾀｸﾞ名称      */
 , FORM_TYPE    VARCHAR (  20 )                                                 /*  90 ﾌｫｰﾑﾀｲﾌﾟ     */
 , FORM_NAME    VARCHAR ( 200 )                                                 /* 100 名称         */
 , FORM_VAL     TEXT                                                            /* 110 値           */
 , DEFAULT_VAL  VARCHAR ( 100 )                                                 /* 120 ﾃﾞﾌｫﾙﾄ値     */
 , LBLCD        VARCHAR (  60 )                                                 /* 130 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR (  20 )                                                 /* 140 ﾒｯｾｰｼﾞID     */
 , MUST         VARCHAR (  10 )                                                 /* 150 必須         */
 , VIEW_SIZE    VARCHAR (  20 )                                                 /* 160 表示桁数     */
 , MAX_SIZE     VARCHAR (  20 )                                                 /* 170 使用桁数     */
 , CODE_CLM     VARCHAR (  30 )                                                 /* 180 ｺｰﾄﾞｶﾗﾑ      */
 , READONLY     VARCHAR (  20 )                                                 /* 190 読取専用     */
 , DISABLED     VARCHAR (  20 )                                                 /* 200 無効         */
 , ROLES        TEXT                                                            /* 210 ﾛｰﾙｽﾞ        */
 , TEXT_DATA    TEXT                                                            /* 220 ﾃｷｽﾄ         */
 , FGOMIT       VARCHAR (   1 )     DEFAULT '0' NOT NULL                        /* 230 除外ﾌﾗｸﾞ     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                 /* 890 更新者       */
);

==> openGion_dev_5.6.9.0.zip: opengion/uap/webapps/gf/db/mysql/sql/install/01_TABLE/GF73S.sql <==
/****************************************************************************/
/* GF73 ( 使用ｶﾗﾑ状態ﾃｰﾌﾞﾙ )                                                */
/*                                                                          */
/* Created : 2013/09/30 18:24:53                                            */
/****************************************************************************/
CREATE TABLE GF73 (
   SYSTEM_ID    VARCHAR (  10 )                 NOT NULL                        /*  10 ｼｽﾃﾑID       */
 , TBLSYU       VARCHAR (   1 )                 NOT NULL                        /*  20 ﾃｰﾌﾞﾙ種別    */
 , ADDRESS      VARCHAR ( 256 )                                                 /*  30 ｱﾄﾞﾚｽ        */
 , FILENAME     VARCHAR (  60 )                                                 /*  40 ﾌｧｲﾙ名       */
 , FILEPATH     VARCHAR ( 256 )                                                 /*  50 ﾌｧｲﾙﾊﾟｽ      */
 , MODIFIED     VARCHAR (  14 )                                                 /*  60 最終更新日   */
 , TAGNAME      VARCHAR (  30 )                                                 /*  80 ﾀｸﾞ名称      */
 , FORM_TYPE    VARCHAR (  20 )                                                 /*  90 ﾌｫｰﾑﾀｲﾌﾟ     */
 , FORM_NAME    TEXT                                                            /* 100 名称         */
 , FORM_VAL     TEXT                                                            /* 110 値           */
 , DEFAULT_VAL  VARCHAR ( 100 )                                                 /* 120 ﾃﾞﾌｫﾙﾄ値     */
 , LBLCD        VARCHAR (  60 )                                                 /* 130 ﾗﾍﾞﾙｺｰﾄﾞ     */
 , MSGCD        VARCHAR (  20 )                                                 /* 140 ﾒｯｾｰｼﾞID     */
 , MUST         VARCHAR (  10 )                                                 /* 150 必須         */
 , VIEW_SIZE    VARCHAR (  20 )                                                 /* 160 表示桁数     */
 , MAX_SIZE     VARCHAR (  20 )                                                 /* 170 使用桁数     */
 , CODE_CLM     VARCHAR (  30 )                                                 /* 180 ｺｰﾄﾞｶﾗﾑ      */
 , READONLY     VARCHAR (  20 )                                                 /* 190 読取専用     */
 , DISABLED     VARCHAR (  20 )                                                 /* 200 無効         */
 , ROLES        TEXT                                                            /* 210 ﾛｰﾙｽﾞ        */
 , TEXT_DATA    TEXT                                                            /* 220 ﾃｷｽﾄ         */
 , FGOMIT       VARCHAR (   1 )     DEFAULT '0' NOT NULL                        /* 230 除外ﾌﾗｸﾞ     */
 , UNIQ         BIGINT                          NOT NULL    AUTO_INCREMENT      /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR (   1 )     DEFAULT '1' NOT NULL                        /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR (  14 )                                                 /* 820 登録日時     */
 , PGSET        VARCHAR (  10 )                                                 /* 830 作成PG       */
 , PGPSET       VARCHAR (  10 )                                                 /* 840 作成親PG     */
 , USRSET       VARCHAR (  10 )                                                 /* 850 作成社員     */
 , DYUPD        VARCHAR (  14 )                                                 /* 860 更新日時     */
 , PGUPD        VARCHAR (  10 )                                                 /* 870 更新PG       */
 , PGPUPD       VARCHAR (  10 )                                                 /* 880 更新親PG     */
 , USRUPD       VARCHAR (  10 )                                                 /* 890 更新者       */
);
